Contributing
------------

For information on how to contribute to Hubtty, please see the
contents of the CONTRIBUTING.rst file.

Bugs
~~~~

Bugs are handled at: https://github.com/hubtty/hubtty/issues
